@@ -7,14 +7,22 @@ use Encode 'decode_utf8';
 use JE;
 
 $je = new JE;
-$je->new_function(peval => sub { local *ARGV = \@_; eval shift });
-$je->new_function($_ => \&$_) for grep /^\w/, @Test::More::EXPORT;
+$je->new_function(peval => sub { local *ARGV = \@_; eval shift })
+	->{forTesting}++;
+$je->new_function($_ => \&$_)->{forTesting}++
+	for grep /^\w/, @Test::More::EXPORT;
 
 {
 	local $/;
 	$code = <DATA>;
 }
 
+my $tests;
+while($code =~ /^\/\/ (\d+) tests?\b/gm) {
+	$tests += $1;
+}
+plan tests => $tests if $tests;
+
 $code = $je->compile(decode_utf8($code), $0, 3);
 $@ and die __FILE__ . ": Couldn't compile $0: $@";
 execute $code;
